
.. image:: https://github.com/mselair/best_toolbox/actions/workflows/test_publish.yml/badge.svg
    :target: https://pypi.org/project/best-toolbox/

.. image:: https://readthedocs.org/projects/best_toolbox/badge/?version=latest
     :target: https://best_toolbox.readthedocs.io/en/latest
     :alt: Documentation Status



BEhavioral STate Analysis Toolbox (BEST)
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

A Python package for behavioral state analysis using EEG.

BEST includes tools automated sleep classification of long-term iEEG data recorded using
implantable neural stimulation and recording devices, removal of DBS artifacts and feature extraction.

The tools were developed in the `Bioelectronics Neurophysiology and Engineering Laboratory <https://www.mayo.edu/research/labs/bioelectronics-neurophysiology-engineering/overview>`_ at Mayo Clinic, Rochester, MN, USA.


Installation
"""""""""""""""""""""""""""

.. code-block:: bash

    pip install best-toolbox


Cite
"""""""""""""""""""""""""""
When use whole, parts, or are inspired by, we appreciate you acknowledge and refer these journal papers:

| Mivalt F, Kremen V, Sladky V, Balzekas I, Nejedly P, Gregg N, Lundstrom BN, Lepkova K, Pridalova T, Brinkmann BH, et al. Electrical brain stimulation and continuous behavioral state tracking in ambulatory humans. J Neural Eng (2022) Available at: http://iopscience.iop.org/article/10.1088/1741-2552/ac4bfd


| Gerla, V., Kremen, V., Macas, M., Dudysova, D., Mladek, A., Sos, P., & Lhotska, L. (2019). Iterative expert-in-the-loop classification of sleep PSG recordings using a hierarchical clustering. Journal of Neuroscience Methods, 317(February), 61?70. https://doi.org/10.1016/j.jneumeth.2019.01.013


| Kremen, V., Brinkmann, B. H., Van Gompel, J. J., Stead, S. (Matt) M., St Louis, E. K., & Worrell, G. A. (2018). Automated Unsupervised Behavioral State Classification using Intracranial Electrophysiology. Journal of Neural Engineering. https://doi.org/10.1088/1741-2552/aae5ab


| Kremen, V., Duque, J. J., Brinkmann, B. H., Berry, B. M., Kucewicz, M. T., Khadjevand, F., G.A. Worrell, G. A. (2017). Behavioral state classification in epileptic brain using intracranial electrophysiology. Journal of Neural Engineering, 14(2), 026001. https://doi.org/10.1088/1741-2552/aa5688


Acknowledgement
"""""""""

BEST was developed under projects supported by NIH Brain Initiative UH2&3 NS095495 Neurophysiologically-Based Brain State Tracking & Modulation in Focal Epilepsy, DARPA HR0011-20-2-0028 Manipulating and Optimizing Brain Rhythms for Enhancement of Sleep (Morpheus).
Filip Mivalt was also partially supported by the grant FEKT-K-22-7649 realized within the project Quality Internal Grants of the Brno University of Technology (KInG BUT), Reg. No. CZ.02.2.69/0.0/0.0/19_073/0016948, which is financed from the OP RDE.


License
""""""""""""""""""

This software is licensed under GNU license. For details see the `LICENSE <https://github.com/mselair/best_toolbox/blob/master/LICENSE>`_ file in the root directory of this project.


Documentation
"""""""""""""""""""""""""""
Documentation is available on `Read the Docs <https://best-toolbox.readthedocs.io/en/latest/>`_.


